@@ -26,10 +26,19 @@
 #ifndef _COMMON_H_
 #define _COMMON_H_
 
-#if defined(WIN32) || defined(_WIN32) || defined(_MSC_VER) || defined(__MINGW32__)
-#define _IS_WINDOWS
+/* MSVC starting include stdint.h fairly recently */
+#if !defined(_MSC_VER) || (MSC_VER >= 1800)
+# include <stdint.h>
 #else
-#undef _IS_WINDOWS
+# include <limits.h>
+  typedef unsigned __int64 uint64_t;
+# if ULONG_MAX == (0xffffffffUL)
+   typedef unsigned long uint32_t;
+# elif UINT_MAX == (0xffffffffUL)
+   typedef unsigned int uint32_t;
+# else
+#  error "Unsupported platform"
+# endif
 #endif
 
 #endif // _COMMON_H_
