@@ -26,8 +26,8 @@
 #ifndef _CRC32C_H_
 #define _CRC32C_H_
 
-#include <stdint.h>
+#include "common.h"
 
-uint32_t _crc32c_intel(uint32_t crc, unsigned const char *data, unsigned long length);
+uint32_t _crc32c_intel(uint32_t crc, const unsigned char *data, unsigned long length);
 
 #endif
